# giteesdk

#### 介绍
gitee的api封装

#### 软件架构
软件架构说明


#### 安装教程

1.  pip安装
```shell script
pip install giteesdk
```
2.  pip安装（使用淘宝镜像加速）
```shell script
pip install giteesdk -i https://mirrors.aliyun.com/pypi/simple
```

#### 使用说明

1.  demo
```python
import giteesdk
gitee_basic = giteesdk.Basic()
gitee_basic.repos()
```

#### 文档

1.  官方主文档：https://gitee.com/api/v5/swagger